==> edge-login-ui-rn-2.12.0.tgz: package/lib/common/locales/strings.js <==
import { getLocales } from 'react-native-localize';
import de from './strings/de.json';
import en from './strings/enUS.json';
import es from './strings/es.json';
import esMX from './strings/esMX.json'; // Requires Crowdin %two_letters_code% override
import fr from './strings/fr.json';
import it from './strings/it.json';
import ja from './strings/ja.json';
import ko from './strings/ko.json';
import pt from './strings/pt.json';
import ru from './strings/ru.json';
import vi from './strings/vi.json';
import zh from './strings/zh.json';
const allLocales = { en, de, ru, es, esMX, it, pt, ja, fr, ko, vi, zh };
const strings = Object.assign({}, en);
const out = { strings };
// Set the language at boot:
const [firstLocale = { languageTag: 'en_US' }] = getLocales();
selectLocale(firstLocale.languageTag);
function mergeStrings(primary, secondary) {
    for (const str of Object.keys(secondary)) {
        if (secondary[str]) {
            primary[str] = secondary[str];
        }
    }
}
// Locale formats can be in the form 'en', 'en-US', 'en_US', or 'enUS'
export function selectLocale(locale = 'en') {
    // Break up local into language and region
    const normalizedLocale = locale.replace('-', '').replace('_', '');
    if (locale === 'en')
        return true;
    // Find an exact match
    // @ts-expect-error
    if (allLocales[normalizedLocale] !== undefined) {
        // @ts-expect-error
        mergeStrings(out.strings, allLocales[normalizedLocale]);
        return true;
    }
    const lang = normalizedLocale.slice(0, 2);
    // Find pure language match first (ie. find 'es' when 'esMX' is chosen)
    // @ts-expect-error
    if (allLocales[lang] !== undefined) {
        // @ts-expect-error
        mergeStrings(out.strings, allLocales[lang]);
        return true;
    }
    return false;
}
export default out;

==> edge-login-ui-rn-3.17.0.tgz: package/lib/common/locales/strings.js <==
import { getLocales } from 'react-native-localize';
import de from './strings/de.json';
import en from './strings/enUS.json';
import es from './strings/es.json';
import esMX from './strings/esMX.json'; // Requires Crowdin %two_letters_code% override
import fr from './strings/fr.json';
import it from './strings/it.json';
import ja from './strings/ja.json';
import ko from './strings/ko.json';
import pt from './strings/pt.json';
import ru from './strings/ru.json';
import vi from './strings/vi.json';
import zh from './strings/zh.json';
const allLocales = { en, de, ru, es, esMX, it, pt, ja, fr, ko, vi, zh };
export const lstrings = Object.assign({}, en);
// Set the language at boot:
const [firstLocale] = getLocales();
const { languageTag = 'en-US' } = firstLocale !== null && firstLocale !== void 0 ? firstLocale : {};
if (languageTag !== 'en-US')
    selectLocale(languageTag);
function mergeStrings(primary, secondary) {
    for (const str of Object.keys(secondary)) {
        if (secondary[str] !== '') {
            primary[str] = secondary[str];
        }
    }
}
// Locale formats can be in the form 'en', 'en-US', 'en_US', or 'enUS'
export function selectLocale(locale) {
    // Break up local into language and region
    const normalizedLocale = locale
        .replace('-', '')
        .replace('-', '')
        .replace('_', '');
    // Find an exact match
    const exactMatch = allLocales[normalizedLocale];
    if (exactMatch != null) {
        mergeStrings(lstrings, exactMatch);
        return true;
    }
    const lang = normalizedLocale.slice(0, 2);
    // Find pure language match first (ie. find 'es' when 'esMX' is chosen)
    const shortMatch = allLocales[lang];
    if (shortMatch != null) {
        mergeStrings(lstrings, shortMatch);
        return true;
    }
    return false;
}
